@@ -1,7 +1,7 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #ifndef ANNOTATIONDIALOG_SHOWSELECTIONONLYMANAGER_H
 #define ANNOTATIONDIALOG_SHOWSELECTIONONLYMANAGER_H
 
@@ -17,11 +17,11 @@ public:
     static ShowSelectionOnlyManager &instance();
     bool selectionIsLimited() const;
 
-public slots:
+public Q_SLOTS:
     void toggle();
     void unlimitFromSelection();
 
-signals:
+Q_SIGNALS:
     void limitToSelected();
     void broaden();
 
