@@ -1,4 +1,6 @@
-// SPDX-FileCopyrightText: 2012-2022 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2012-2013 Jesper K. Pedersen <jesper.pedersen@kdab.com>
+// SPDX-FileCopyrightText: 2013-2024 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Tobias Leupold <tl@stonemx.de>
 //
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -13,6 +15,7 @@ namespace ImageManager
 {
 class ImageRequest;
 class ThumbnailCache;
+class VideoThumbnailCache;
 }
 namespace DB
 {
@@ -27,13 +30,9 @@ class HandleVideoThumbnailRequestJob : public BackgroundTaskManager::JobInterfac
 {
     Q_OBJECT
 public:
-    explicit HandleVideoThumbnailRequestJob(ImageManager::ImageRequest *request, BackgroundTaskManager::Priority priority, ImageManager::ThumbnailCache *thumbnailCache);
+    explicit HandleVideoThumbnailRequestJob(ImageManager::ImageRequest *request, BackgroundTaskManager::Priority priority, ImageManager::ThumbnailCache *thumbnailCache, ImageManager::VideoThumbnailCache *videoThumbnailCache);
     QString title() const override;
     QString details() const override;
-    static void saveFullScaleFrame(const DB::FileName &fileName, const QImage &image);
-    static DB::FileName pathForRequest(const DB::FileName &fileName);
-    static DB::FileName frameName(const DB::FileName &videoName, int frameNumber);
-    static void removeFullScaleFrame(const DB::FileName &fileName);
 
 protected:
     void execute() override;
@@ -47,6 +46,7 @@ private:
 
     ImageManager::ImageRequest *m_request;
     ImageManager::ThumbnailCache *m_thumbnailCache;
+    ImageManager::VideoThumbnailCache *m_videoThumbnailCache;
 };
 
 } // namespace BackgroundJobs
