@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2012 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2012-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef BACKGROUNDTASKS_STATUSINDICATOR_H
 #define BACKGROUNDTASKS_STATUSINDICATOR_H
@@ -26,7 +25,7 @@ public:
 protected:
     void mouseReleaseEvent(QMouseEvent *event) override;
 
-private slots:
+private Q_SLOTS:
     void flicker();
     void maybeStartFlicker();
 
