@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2003-2015 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef TREECATEGORYMODEL_H
 #define TREECATEGORYMODEL_H
@@ -74,7 +73,7 @@ public:
         QString tagGroup;
     };
 
-signals:
+Q_SIGNALS:
     void dataChanged();
 
 private: // Functions
