@@ -1,8 +1,8 @@
-/* SPDX-FileCopyrightText: 2018 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-   SPDX-FileCopyrightText: 2007-2010 Tuomas Suutari <thsuut@utu.fi>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2007-2010 Tuomas Suutari <thsuut@utu.fi>
+// SPDX-FileCopyrightText: 2018 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2014-2020 Tobias Leupold <tl@stonemx.de>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "MD5.h"
 
@@ -26,8 +26,8 @@ DB::MD5::MD5()
 
 DB::MD5::MD5(const QString &md5str)
     : m_isNull(md5str.isEmpty())
-    , m_v0(md5str.leftRef(16).toULongLong(nullptr, 16))
-    , m_v1(md5str.midRef(16, 16).toULongLong(nullptr, 16))
+    , m_v0(md5str.left(16).toULongLong(nullptr, 16))
+    , m_v1(md5str.mid(16, 16).toULongLong(nullptr, 16))
 {
 }
 
@@ -42,8 +42,8 @@ DB::MD5 &DB::MD5::operator=(const QString &md5str)
         m_isNull = true;
     } else {
         m_isNull = false;
-        m_v0 = md5str.leftRef(16).toULongLong(nullptr, 16);
-        m_v1 = md5str.midRef(16, 16).toULongLong(nullptr, 16);
+        m_v0 = md5str.left(16).toULongLong(nullptr, 16);
+        m_v1 = md5str.mid(16, 16).toULongLong(nullptr, 16);
     }
     return *this;
 }
