@@ -5,10 +5,10 @@
 // SPDX-FileCopyrightText: 2008-2009 Henner Zeller <h.zeller@acm.org>
 // SPDX-FileCopyrightText: 2008-2011 Jan Kundrát <jkt@flaska.net>
 // SPDX-FileCopyrightText: 2012-2013 Miika Turkia <miika.turkia@gmail.com>
-// SPDX-FileCopyrightText: 2012-2025 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 // SPDX-FileCopyrightText: 2012 Yuri Chornoivan <yurchor@ukr.net>
-// SPDX-FileCopyrightText: 2014-2024 Tobias Leupold <tl@stonemx.de>
 // SPDX-FileCopyrightText: 2018-2020 Robert Krawitz <rlk@alum.mit.edu>
+// SPDX-FileCopyrightText: 2012-2025 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2014-2025 Tobias Leupold <tl@stonemx.de>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -72,6 +72,7 @@ void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
 
     // prepare XML document for saving:
     m_db->m_categoryCollection.initIdMap();
+
     QFile out(fileName + QStringLiteral(".tmp"));
     if (!out.open(QIODevice::WriteOnly | QIODevice::Text)) {
         m_db->uiDelegate().error(
@@ -146,6 +147,7 @@ void DB::FileWriter::saveCategories(QXmlStreamWriter &writer)
 
         ElementWriter dummy(writer, QStringLiteral("Category"));
         writer.writeAttribute(QStringLiteral("name"), name);
+        writer.writeAttribute(QStringLiteral("id"), QString::number(category->id()));
         writer.writeAttribute(QStringLiteral("icon"), category->iconName());
         writer.writeAttribute(QStringLiteral("show"), QString::number(category->doShow()));
         writer.writeAttribute(QStringLiteral("viewtype"), QString::number(category->viewType()));
@@ -402,8 +404,6 @@ void DB::FileWriter::writeCategories(QXmlStreamWriter &writer, const DB::ImageIn
 
 void DB::FileWriter::writeCategoriesCompressed(QXmlStreamWriter &writer, const DB::ImageInfoPtr &info)
 {
-    QMap<QString, QList<QPair<QString, QRect>>> positionedTags;
-
     const QList<DB::CategoryPtr> categoryList = DB::ImageDB::instance()->categoryCollection()->categories();
     for (const DB::CategoryPtr &category : categoryList) {
         QString categoryName = category->name();
@@ -416,49 +416,19 @@ void DB::FileWriter::writeCategoriesCompressed(QXmlStreamWriter &writer, const D
             QStringList idList;
 
             for (const QString &itemValue : items) {
-                QRect area = info->areaForTag(categoryName, itemValue);
+                auto idString = QString::number(category->idForName(itemValue));
 
+                const auto area = info->areaForTag(categoryName, itemValue);
                 if (area.isValid()) {
-                    // Positioned tags can't be stored in the "fast" format
-                    // so we have to handle them separately
-                    positionedTags[categoryName] << QPair<QString, QRect>(itemValue, area);
-                } else {
-                    int id = category->idForName(itemValue);
-                    idList.append(QString::number(id));
+                    idString.append(QStringLiteral("+a=%1").arg(areaToString(area)));
                 }
+
+                idList.append(idString);
             }
 
-            // Possibly all ids of a category have area information, so only
-            // write the category attribute if there are actually ids to write
-            if (!idList.isEmpty()) {
-                std::sort(idList.begin(), idList.end());
-                writer.writeAttribute(escape(categoryName), idList.join(QStringLiteral(",")));
-            }
-        }
-    }
-
-    // Add a "readable" sub-element for the positioned tags
-    // FIXME: can this be merged with the code in writeCategories()?
-    if (!positionedTags.isEmpty()) {
-        ElementWriter topElm(writer, QStringLiteral("options"), false);
-        topElm.writeStartElement();
-
-        QMapIterator<QString, QList<QPair<QString, QRect>>> categoryWithAreas(positionedTags);
-        while (categoryWithAreas.hasNext()) {
-            categoryWithAreas.next();
-
-            ElementWriter categoryElm(writer, QStringLiteral("option"), false);
-            categoryElm.writeStartElement();
-            writer.writeAttribute(QStringLiteral("name"), categoryWithAreas.key());
-
-            QList<QPair<QString, QRect>> areas = categoryWithAreas.value();
-            std::sort(areas.begin(), areas.end(),
-                      [](QPair<QString, QRect> a, QPair<QString, QRect> b) { return a.first < b.first; });
-            for (const auto &positionedTag : std::as_const(areas)) {
-                ElementWriter dummy(writer, QStringLiteral("value"));
-                writer.writeAttribute(QStringLiteral("value"), positionedTag.first);
-                writer.writeAttribute(QStringLiteral("area"), areaToString(positionedTag.second));
-            }
+            std::sort(idList.begin(), idList.end());
+            writer.writeAttribute(QStringLiteral("tags_%1").arg(category->id()),
+                                  idList.join(QStringLiteral(",")));
         }
     }
 }
@@ -484,49 +454,4 @@ bool DB::FileWriter::shouldSaveCategory(const QString &categoryName) const
     return shouldSave;
 }
 
-/**
- * @brief Escape problematic characters in a string that forms an XML attribute name.
- *
- * N.B.: Attribute values do not need to be escaped!
- * @see DB::FileReader::unescape
- *
- * @param str the string to be escaped
- * @return the escaped string
- */
-QString DB::FileWriter::escape(const QString &str)
-{
-    static bool hashUsesCompressedFormat = useCompressedFileFormat();
-    static QHash<QString, QString> s_cache;
-    if (hashUsesCompressedFormat != useCompressedFileFormat())
-        s_cache.clear();
-
-    if (s_cache.contains(str))
-        return s_cache[str];
-
-    QString escaped;
-
-    // Encoding special characters if compressed XML is selected
-    if (useCompressedFileFormat()) {
-        static const QRegularExpression rx(QStringLiteral("([^a-zA-Z0-9:_])"));
-        QString tmp(str);
-        while (true) {
-            const auto match = rx.match(tmp);
-            if (match.hasMatch()) {
-                escaped += tmp.left(match.capturedStart())
-                    + QString::asprintf("_.%0X", match.captured().data()->toLatin1());
-                tmp = tmp.mid(match.capturedStart() + match.capturedLength(), -1);
-            } else {
-                escaped += tmp;
-                break;
-            }
-        }
-    } else {
-        escaped = str;
-        escaped.replace(QStringLiteral(" "), QStringLiteral("_"));
-    }
-
-    s_cache.insert(str, escaped);
-    return escaped;
-}
-
 // vi:expandtab:tabstop=4 shiftwidth=4:
