@@ -1,10 +1,10 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef CATEGORYIMAGEPOPUP_H
 #define CATEGORYIMAGEPOPUP_H
+
 #include <DB/ImageDB.h>
 
 #include <QImage>
@@ -21,7 +21,7 @@ public:
     explicit CategoryImagePopup(QWidget *parent);
     void populate(const QImage &image, const DB::FileName &imageName);
 
-protected slots:
+protected Q_SLOTS:
     void slotExecuteService(QAction *);
     void makeCategoryImage();
 
