@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-// SPDX-FileCopyrightText: 2020 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2020-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -23,10 +23,6 @@ class ImageInfo;
 namespace MainWindow
 {
 
-using Utilities::StringSet;
-
-typedef QSet<KService::Ptr> OfferType;
-
 class ExternalPopup : public QMenu
 {
     Q_OBJECT
@@ -37,19 +33,26 @@ public:
 
 protected:
     QString mimeType(const DB::FileName &file);
-    StringSet mimeTypes(const DB::FileNameList &files);
-    OfferType appInfos(const DB::FileNameList &files);
+    Utilities::StringSet mimeTypes(const DB::FileNameList &files);
+    /**
+     * @brief appInfos gets a list of KService entries for the list of files.
+     * The result list only contains entries that are valid for all files and is sorted by preference.
+     * Note that "sorted by preference" means sorted by one of the mime types, so if the user has vastly different preferences for different mime types they might still end up with a somewhat random order.
+     * @param files
+     * @return
+     */
+    KService::List appInfos(const DB::FileNameList &files);
 
 private:
     enum class PopupAction { OpenCurrent,
                              OpenAllSelected,
                              CopyAndOpenAllSelected };
     void runService(KService::Ptr servicel, QList<QUrl> urls);
-    QList<QUrl> relevantUrls(PopupAction which, KService::Ptr service);
+    QList<QUrl> relevantUrls(PopupAction which);
 
     DB::FileNameList m_list;
     DB::ImageInfoPtr m_currentInfo;
-    QMap<QString, StringSet> m_appToMimeTypeMap;
+    QMap<QString, Utilities::StringSet> m_appToMimeTypeMap;
 };
 }
 
