@@ -1,7 +1,8 @@
-/* SPDX-FileCopyrightText: 2016-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2016 - 2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2025 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
 #include "Options.h"
 
 #include "Logging.h"
@@ -25,6 +26,11 @@ public:
         i18n("Use <databaseFile> instead of the default. Deprecated - use '--db <databaseFile>' instead."),
         i18n("databaseFile")
     };
+    QCommandLineOption config {
+        QLatin1String("config"),
+        i18n("Application rc file."),
+        i18n("kphotoalbumrc")
+    };
     QCommandLineOption dbFile {
         QLatin1String("db"),
         i18n("Use <databaseFile> instead of the default."),
@@ -49,6 +55,7 @@ public:
         i18n("interface_address")
     };
 #endif
+    QCommandLineOption saveAndQuit { QLatin1String("save-and-quit"), i18n("Save the database and immediately quit after showing the main window.") };
     QCommandLineOption searchOnStartup { QLatin1String("search"), i18n("Search for new images on startup.") };
 };
 }
@@ -65,6 +72,11 @@ QCommandLineParser *MainWindow::Options::parser() const
     return &(d->parser);
 }
 
+QString MainWindow::Options::config() const
+{
+    return d->parser.value(d->config);
+}
+
 QUrl MainWindow::Options::dbFile() const
 {
     QUrl db;
@@ -110,6 +122,11 @@ QHostAddress MainWindow::Options::listen() const
 #endif
 }
 
+bool MainWindow::Options::saveAndQuit() const
+{
+    return d->parser.isSet(d->saveAndQuit);
+}
+
 bool MainWindow::Options::searchForImagesOnStart() const
 {
     return d->parser.isSet(d->searchOnStartup);
@@ -122,6 +139,7 @@ MainWindow::Options::Options()
     d->parser.addOptions(
         QList<QCommandLineOption>()
         << d->configFile
+        << d->config
         << d->dbFile
         << d->demoOption
         << d->importFile
@@ -129,6 +147,7 @@ MainWindow::Options::Options()
         << d->listen
         << d->listenAddress
 #endif
+        << d->saveAndQuit
         << d->searchOnStartup);
 }
 
