@@ -1,7 +1,9 @@
-/* SPDX-FileCopyrightText: 2016 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+/*
+ * SPDX-FileCopyrightText: 2016 - 2025 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
@@ -28,6 +30,16 @@ public:
      */
     QCommandLineParser *parser() const;
 
+    /**
+     * @brief config
+     *
+     * Note: this value is not directly used in kphotoalbum, but by KSharedConfig::openConfig.
+     * It needs to be allowed (and documented) as a commandline option here so that it is available for KConfig::mainConfigName() to use.
+     *
+     * @return the path to kphotoalbumrc
+     */
+    QString config() const;
+
     /**
      * @brief dbFile
      * @return the XML database file specified on the command line, if any.
@@ -45,12 +57,24 @@ public:
      * @return the QUrl of the import file, or an empty QUrl, if no import file is set.
      */
     QUrl importFile() const;
+
     /**
      * @brief listen
      * Access the address that was givent to the commandline "--listen" argument.
      * @return a null address if listening is disabled, otherwise an address to bind to.
      */
     QHostAddress listen() const;
+
+    /**
+     * @brief saveAndQuit
+     * Immediately save the database and quit after showing the main window.
+     * This can be used by automated testing, but also to search for new images an exit immediately aferwards.
+     *
+     * Note: KPhotoAlbum may still show some interactive dialog that causes the window to stay open longer than anticipated.
+     * @return
+     */
+    bool saveAndQuit() const;
+
     /**
      * @brief searchOnStartup
      * @return true, if we want to search for images on startup
