@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -37,21 +37,21 @@ bool MainWindow::SearchBar::eventFilter(QObject *, QEvent *e)
     if (e->type() == QEvent::KeyPress) {
         QKeyEvent *ke = static_cast<QKeyEvent *>(e);
         if (ke->key() == Qt::Key_Up || ke->key() == Qt::Key_Down || ke->key() == Qt::Key_Left || ke->key() == Qt::Key_Right || ke->key() == Qt::Key_PageDown || ke->key() == Qt::Key_PageUp || ke->key() == Qt::Key_Home || ke->key() == Qt::Key_End) {
-            emit movementKeyPressed(ke);
+            Q_EMIT movementKeyPressed(ke);
             return true;
         } else if (ke->key() == Qt::Key_Enter || ke->key() == Qt::Key_Return) {
             // If I don't interpret return and enter here, but simply rely
-            // on QLineEdit itself to emit the signal, then it will
+            // on QLineEdit itself to Q_EMIT the signal, then it will
             // propagate to the main window, and from there be delivered to
             // the central widget.
-            emit returnPressed();
+            Q_EMIT returnPressed();
             return true;
         } else if (ke->key() == Qt::Key_Escape)
             clear();
     }
     if (e->type() == QEvent::FocusIn) {
         // this ensures that BrowserWidget::slotLimitToMatch is called when the search bar is activated
-        emit textChanged(m_edit->text());
+        Q_EMIT textChanged(m_edit->text());
     }
     return false;
 }
@@ -59,7 +59,7 @@ bool MainWindow::SearchBar::eventFilter(QObject *, QEvent *e)
 void MainWindow::SearchBar::clear()
 {
     m_edit->clear();
-    emit cleared();
+    Q_EMIT cleared();
 }
 
 void MainWindow::SearchBar::setLineEditEnabled(bool enabled)
