@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2024 Tobias Leupold <tl@stonemx.de>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -159,7 +159,7 @@ void MainWindow::StatusBar::hideThumbnailSlider()
     m_thumbnailSettings->hide();
 }
 
-void MainWindow::StatusBar::enterEvent(QEvent *)
+void MainWindow::StatusBar::enterEvent(QEnterEvent *)
 {
     // make sure that breadcrumbs are not obscured by messages
     clearMessage();
