@@ -1,7 +1,8 @@
-/* SPDX-FileCopyrightText: 2003-2020 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2020 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #include "CellGeometry.h"
 
 #include "ThumbnailModel.h"
@@ -16,7 +17,6 @@ using Utilities::StringSet;
 
 ThumbnailView::CellGeometry::CellGeometry(ThumbnailFactory *factory)
     : ThumbnailComponent(factory)
-    , m_cacheInitialized(false)
 {
 }
 
