@@ -1,5 +1,6 @@
-// SPDX-FileCopyrightText: 2019-2022 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2019 - 2022 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2024 Tobias Leupold <tl@stonemx.de>
+// SPDX-FileCopyrightText: 2025 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -31,7 +32,7 @@ ThumbnailView::FilterWidget::FilterWidget(QWidget *parent)
         QAction *ratingAction = new QAction(i18np("Filter view by rating: %1 star", "Filter view by rating: %1 stars", i));
         m_actions->addAction(QString::fromLatin1("FilterWidget/rating/%1").arg(i), ratingAction);
         m_actions->setDefaultShortcut(ratingAction, QKeySequence(Qt::ALT | (Qt::Key_0 + i)));
-        connect(ratingAction, &QAction::triggered, this, [=]() {
+        connect(ratingAction, &QAction::triggered, this, [=, this]() {
             short rating = i * 2;
             if (static_cast<short>(m_rating->rating()) == rating)
                 rating = -1;
