@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -36,7 +36,7 @@ public:
     bool keyPressEvent(QKeyEvent *event);
     bool keyReleaseEvent(QKeyEvent *);
 
-signals:
+Q_SIGNALS:
     void showSelection();
     void showSearch();
 
