@@ -1,7 +1,7 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #ifndef MOUSETRACKINGINTERACTION_H
 #define MOUSETRACKINGINTERACTION_H
 
@@ -26,7 +26,7 @@ public:
     explicit MouseTrackingInteraction(ThumbnailFactory *factory);
     bool mouseMoveEvent(QMouseEvent *) override;
 
-signals:
+Q_SIGNALS:
     void fileIdUnderCursorChanged(const DB::FileName &id);
 
 private:
