@@ -1,7 +1,16 @@
-// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021-2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-//
-// SPDX-License-Identifier: GPL-2.0-or-later
+/*
+ * SPDX-FileCopyrightText: 2006-2013 Jesper K. Pedersen <jesper.pedersen@kdab.com>
+ * SPDX-FileCopyrightText: 2007 Dirk Mueller <mueller@kde.org>
+ * SPDX-FileCopyrightText: 2007 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2007-2008 Jan Kundrát <jkt@flaska.net>
+ * SPDX-FileCopyrightText: 2007-2010 Tuomas Suutari <tuomas@nepnep.net>
+ * SPDX-FileCopyrightText: 2008 Henner Zeller <h.zeller@acm.org>
+ * SPDX-FileCopyrightText: 2012-2024 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+ * SPDX-FileCopyrightText: 2013 Dominik Broj <broj.dominik@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Robert Krawitz <rlk@alum.mit.edu>
+ * SPDX-FileCopyrightText: 2022 Tobias Leupold <tl@stonemx.de>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef THUMBNAILVIEW_THUMBNAILWIDGET_H
 #define THUMBNAILVIEW_THUMBNAILWIDGET_H
@@ -103,8 +112,7 @@ private Q_SLOTS:
 
 private:
     friend class GridResizeInteraction;
-    inline ThumbnailModel *model() { return ThumbnailComponent::model(); }
-    inline const ThumbnailModel *model() const { return ThumbnailComponent::model(); }
+    using ThumbnailComponent::model;
     void updatePalette();
     void setupDateChangeTimer();
 
