@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2012 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2012-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef VIDEOTHUMBNAILCYCLER_H
 #define VIDEOTHUMBNAILCYCLER_H
@@ -40,7 +39,7 @@ public:
     void setActive(const DB::FileName &id);
     void stopCycle();
 
-private slots:
+private Q_SLOTS:
     void gotFrame(const QImage &image);
 
 private:
