@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2012 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2012-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef UTILITIES_DELETEFILES_H
 #define UTILITIES_DELETEFILES_H
@@ -9,6 +8,7 @@
 #include <kpabase/FileNameList.h>
 
 #include <QObject>
+
 class KJob;
 
 namespace Utilities
@@ -25,7 +25,7 @@ class DeleteFiles : public QObject
 public:
     static bool deleteFiles(const DB::FileNameList &files, DeleteMethod method);
 
-private slots:
+private Q_SLOTS:
     void slotKIOJobCompleted(KJob *);
 
 private:
