@@ -1,10 +1,7 @@
 /*
-  Copyright (C) 2006-2020 Tuomas Suutari <thsuut@utu.fi>
+  SPDX-FileCopyrightText: 2006-2020 Tuomas Suutari <thsuut@utu.fi>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  SPDX-License-Identifier: GPL-2.0-or-later
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,8 +16,8 @@
 
 #include "List.h"
 
-#include <DB/FileName.h>
 #include <DB/RawId.h>
+#include <kpabase/FileName.h>
 
 #include <QList>
 #include <QStringList>
