@@ -1,26 +1,13 @@
-/* Copyright (C) 2008-2010 Henner Zeller <h.zeller@acm.org>
+/* SPDX-FileCopyrightText: 2008-2010 Henner Zeller <h.zeller@acm.org>
 
    based on Utilities::createUniqNameMap() by <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef UTILITIES_UNIQ_FILENAME_MAPPER_H
 #define UTILITIES_UNIQ_FILENAME_MAPPER_H
 
-#include <DB/FileName.h>
+#include <kpabase/FileName.h>
 
 #include <QMap>
 #include <QSet>
