@@ -14,4 +14,11 @@ Viewer::AbstractDisplay::AbstractDisplay(QWidget *parent)
 {
 }
 
+bool Viewer::AbstractDisplay::setImage(DB::ImageInfoPtr info, bool forward)
+{
+    m_info = info;
+    return setImageImpl(info, forward);
+}
+
+#include "moc_AbstractDisplay.cpp"
 // vi:expandtab:tabstop=4 shiftwidth=4:
