@@ -1,4 +1,5 @@
 // SPDX-FileCopyrightText: 2006-2022 Ricardo Villalba <rvm@escomposlinux.org>
+// SPDX-FileCopyrightText: 2024 Tobias Leupold <tl@stonemx.de>
 //
 // SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Trolltech-FreeQtFoundation-Accepted-LGPL
 
@@ -67,7 +68,7 @@ int Slider::pixelPosToRangeValue(int pos) const
                                            sliderMax - sliderMin, opt.upsideDown);
 }
 
-void Slider::enterEvent(QEvent *event)
+void Slider::enterEvent(QEnterEvent *event)
 {
     Q_EMIT onEnter();
     QSlider::enterEvent(event);
@@ -83,7 +84,7 @@ void Slider::mouseMoveEvent(QMouseEvent *e)
 {
     const int o = style()->pixelMetric(QStyle::PM_SliderLength) - 1;
     int v = QStyle::sliderValueFromPosition(minimum(), maximum(), e->pos().x() - o / 2, width() - o, false);
-    Q_EMIT onHover(e->globalPos(), v);
+    Q_EMIT onHover(e->globalPosition().toPoint(), v);
     QSlider::mouseMoveEvent(e);
 }
 
