@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-// SPDX-FileCopyrightText: 2023 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2023-2024 Tobias Leupold <tl@stonemx.de>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -14,20 +14,23 @@
 
 #include <QFile>
 #include <QFileInfo>
-#include <QTextCodec>
 #include <exiv2/exv_conf.h>
 #include <exiv2/image.hpp>
 
+#include <QStringDecoder>
+
 using namespace Exif;
 
 namespace
 {
 QString cStringWithEncoding(const char *c_str, const QString &charset)
 {
-    QTextCodec *codec = QTextCodec::codecForName(charset.toLatin1());
-    if (!codec)
-        codec = QTextCodec::codecForLocale();
-    return codec->toUnicode(c_str);
+    // FIXME KF6 port: Check if this does what it should do
+    auto codec = QStringDecoder(charset.toUtf8().data());
+    if (!codec.isValid()) {
+        codec = QStringDecoder(QStringConverter::System);
+    }
+    return codec.decode(QByteArray::fromRawData(c_str, sizeof(c_str)));
 }
 
 } // namespace
